<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>InsertScriptItem</name>
    <message>
        <location filename="../InsertScriptItemInit.js" line="+2"/>
        <source>Insert &amp;Script</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
